#
# spec file for package python-jaraco.stream
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   jaraco.stream
Name:           python-jaraco.stream
Version:        3.0.3
Release:        2.5
Summary:        Routines for dealing with data streams
License:        MIT
URL:            https://github.com/jaraco/jaraco.stream
Source:         https://files.pythonhosted.org/packages/source/j/%{_name}/%{_name}-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 56}
BuildRequires:  %{python_module setuptools_scm >= 3.4.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-more-itertools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module more-itertools}
BuildRequires:  %{python_module pytest}
# /SECTION
# SECTION documentation requirements
BuildRequires:  python3-Sphinx
# Require offline feature introduced in  gh#jaraco/jaraco.packaging#11
BuildRequires:  python3-jaraco.packaging >= 9.2
BuildRequires:  python3-pylons-sphinx-themes
BuildRequires:  python3-rst.linker >= 1.9
# /SECTION
%python_subpackages

%description
Routines for handling streaming data, including a set of generators
for loading gzip data on the fly.

%package     -n %{name}-doc
Summary:        Documentation files for %{name}
Provides:       %{python_module jaraco.stream-doc = %{version}}

%description -n %{name}-doc
This package contains documentation files for %{name}.

%prep
%setup -q -n %{_name}-%{version}
rm -rf jaraco.stream.egg-info

%build
%pyproject_wheel
export JARACO_PACKAGING_SPHINX_WHEEL=./dist/jaraco.stream-%{version}-py3-none-any.whl
sphinx-build -b html docs/ build/sphinx/html/
rm -r build/sphinx/html/{.buildinfo,.doctrees}

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README.rst
%dir %{python_sitelib}/jaraco
%{python_sitelib}/jaraco/stream/
%{python_sitelib}/jaraco.stream-%{version}*-info

%files -n %{name}-doc
%doc build/sphinx/html

%changelog
* Fri May 12 2023 Ben Greiner <code@bnavigator.de>
- Replace removed sphinx_build setuptools hook with build-sphinx
  * requires feature enhancement of python-jaraco.packaging
    gh#jaraco/jaraco.packaging#11
- Remove obsolete pytest workaround
* Mon Aug 29 2022 Ben Greiner <code@bnavigator.de>
- Update to 3.0.3
  * Refreshed package metadata.
  * #3: Fixed issue in tests where the connection to the test
    server would fail on hosts where localhost resolved to ::1. Now
    the test server binds to IPv6 when available and appropriate.
- v3.0.2: Rely on PEP 420 for namespace packages.
- v3.0.1: Refresh package metadata.
- Switch to PEP517 and remove obsolete jaraco.base requirement
* Mon Mar  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.0.0
  * Drop support for Python 3.5 and earlier (including Python 2).
  * Adopt black for code style and other updates from jaraco/skeleton.
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Add LICENSE
- Compile manually due to switch to pkgutil namespace technique
- Remove bcond_with test, allowing tests suite to run
- Remove undesirable build dependencies pytest-flake8 and pytest-runner
- Add missing runtime dependency on six
- Add explicit build dependency on python-six
- Update to v2.0
  * Switch to pkgutil namespace technique for the ``jaraco`` namespace.
* Sat Jul 28 2018 jengelh@inai.de
- Fix RPM groups.
* Tue Jun 26 2018 mcepl@suse.com
- Upgrade to 1.2:
  Added ``jaraco.stream.Tee`` from jaraco.util 11
- Clean up SPEC to full singlespec.
* Mon Nov 13 2017 toddrme2178@gmail.com
- Properly handle namespace package structure.
  This guarantees the module is importable.
* Tue Jul  4 2017 aloisio@gmx.com
- Update to version 1.1.2
  * Refresh packaging.
- Create -doc package
- Converted to single-spec
* Sat Jul 30 2016 sor.alexei@meowr.ru
- Initial package.
